Installation
============

Ceci requires python 3.  It can be installed using pip:

.. code-block:: bash

    pip install ceci


Or from source like this:

.. code-block:: bash

    git clone https://github.com/LSSTDESC/ceci
    cd ceci
    python3 setup.py install


